/* $Id: cpl_frame_impl.h,v 1.3 2012/01/11 13:38:29 rpalsa Exp $
 *
 * This file is part of the ESO Common Pipeline Library
 * Copyright (C) 2001-2006 European Southern Observatory
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
 */

/*
 * $Author: rpalsa $
 * $Date: 2012/01/11 13:38:29 $
 * $Revision: 1.3 $
 * $Name: cpl-6_0 $
 */

#ifndef CPL_FRAME_IMPL_H
#define CPL_FRAME_IMPL_H

#include "cpl_type.h"
#include "cpl_frame.h"

CPL_BEGIN_DECLS

/* Private functions */
cpl_size cpl_frame_get_nplanes(const cpl_frame *self, cpl_size extnum);

CPL_END_DECLS

#endif /* CPL_MODULE_H */
